@@ -131,7 +131,9 @@ class FlaviusEnvironment(FlaviusBase):
     """
     def __init__(self):
         super(FlaviusEnvironment, self).__init__(search_url=conf.FLAVIUS_API_ENVIRONMENT_SEARCH,
-                                                 create_url='', update_url='', delete_url='')
+                                                 create_url=conf.FLAVIUS_API_ENVIRONMENT_SET,
+                                                 update_url=conf.FLAVIUS_API_ENVIRONMENT_SET,
+                                                 delete_url='')
 
 
 class FlaviusSort(FlaviusBase):
